==> silktools-0.11.7.tbz: include/silk/skprintnets.h <==
/*
** Copyright (C) 2005-2006 by Carnegie Mellon University.
**
** @OPENSOURCE_HEADER_START@
**
** Use of the SILK system and related source code is subject to the terms
** of the following licenses:
**
** GNU Public License (GPL) Rights pursuant to Version 2, June 1991
** Government Purpose License Rights (GPLR) pursuant to DFARS 252.225-7013
**
** NO WARRANTY
**
** ANY INFORMATION, MATERIALS, SERVICES, INTELLECTUAL PROPERTY OR OTHER
** PROPERTY OR RIGHTS GRANTED OR PROVIDED BY CARNEGIE MELLON UNIVERSITY
** PURSUANT TO THIS LICENSE (HEREINAFTER THE "DELIVERABLES") ARE ON AN
** "AS-IS" BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY
** KIND, EITHER EXPRESS OR IMPLIED AS TO ANY MATTER INCLUDING, BUT NOT
** LIMITED TO, WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE,
** MERCHANTABILITY, INFORMATIONAL CONTENT, NONINFRINGEMENT, OR ERROR-FREE
** OPERATION. CARNEGIE MELLON UNIVERSITY SHALL NOT BE LIABLE FOR INDIRECT,
** SPECIAL OR CONSEQUENTIAL DAMAGES, SUCH AS LOSS OF PROFITS OR INABILITY
** TO USE SAID INTELLECTUAL PROPERTY, UNDER THIS LICENSE, REGARDLESS OF
** WHETHER SUCH PARTY WAS AWARE OF THE POSSIBILITY OF SUCH DAMAGES.
** LICENSEE AGREES THAT IT WILL NOT MAKE ANY WARRANTY ON BEHALF OF
** CARNEGIE MELLON UNIVERSITY, EXPRESS OR IMPLIED, TO ANY PERSON
** CONCERNING THE APPLICATION OF OR THE RESULTS TO BE OBTAINED WITH THE
** DELIVERABLES UNDER THIS LICENSE.
**
** Licensee hereby agrees to defend, indemnify, and hold harmless Carnegie
** Mellon University, its trustees, officers, employees, and agents from
** all claims or demands made against them (and any related losses,
** expenses, or attorney's fees) arising out of, or relating to Licensee's
** and/or its sub licensees' negligent use or willful misuse of or
** negligent conduct or willful misconduct regarding the Software,
** facilities, or other rights or assistance granted by Carnegie Mellon
** University under this License, including, but not limited to, any
** claims of product liability, personal injury, death, damage to
** property, or violation of any laws or regulations.
**
** Carnegie Mellon University Software Engineering Institute authored
** documents are sponsored by the U.S. Department of Defense under
** Contract F19628-00-C-0003. Carnegie Mellon University retains
** copyrights in all material produced under this contract. The U.S.
** Government retains a non-exclusive, royalty-free license to publish or
** reproduce these documents, or allow others to do so, for U.S.
** Government purposes only pursuant to the copyright license under the
** contract clause at 252.227.7013.
**
** @OPENSOURCE_HEADER_END@
*/
#ifndef _PRINT_NETWORK_STRUCTURE_H
#define _PRINT_NETWORK_STRUCTURE_H

#include "silk.h"

RCSIDENTVAR(rcsID_PRINT_NETWORK_STRUCTURE_H, "$SiLK: skprintnets.h 8269 2007-08-03 18:54:48Z mthomas $");

#include "iptree.h"


typedef struct netStruct netStruct_t;


int netStructureCreate(
    netStruct_t   **ns,
    int             has_count);

void netStructureSetOutputStream(
    netStruct_t     *ns,
    skstream_t      *stream);

void netStructureDestroy(netStruct_t **ns);

void netStructureSetCountWidth(
    netStruct_t            *ns,
    int                     width);

void netStructureSetNoColumns(netStruct_t *ns);

void netStructureSetIpFormat(
    netStruct_t            *ns,
    skIPTreeFormats_t       format);

void netStructureSetDelimiter(
    netStruct_t     *ns,
    char             delimiter);

int netStructureParse(
    netStruct_t    *ns,
    const char     *input);


void netStructurePrintIP(
    uint32_t        ip, 
    uint64_t       *count,
    netStruct_t    *ns);

void netStructurePrintFinalize(netStruct_t *ns);

void netStructurePrintStatistics(netStruct_t *ns);

#endif /* _PRINT_NETWORK_STRUCTURE_H */

==> silktools-2.3.1_1.tbz: include/silk/skprintnets.h <==
/*
** Copyright (C) 2005-2010 by Carnegie Mellon University.
**
** @OPENSOURCE_HEADER_START@
**
** Use of the SILK system and related source code is subject to the terms
** of the following licenses:
**
** GNU Public License (GPL) Rights pursuant to Version 2, June 1991
** Government Purpose License Rights (GPLR) pursuant to DFARS 252.227.7013
**
** NO WARRANTY
**
** ANY INFORMATION, MATERIALS, SERVICES, INTELLECTUAL PROPERTY OR OTHER
** PROPERTY OR RIGHTS GRANTED OR PROVIDED BY CARNEGIE MELLON UNIVERSITY
** PURSUANT TO THIS LICENSE (HEREINAFTER THE "DELIVERABLES") ARE ON AN
** "AS-IS" BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY
** KIND, EITHER EXPRESS OR IMPLIED AS TO ANY MATTER INCLUDING, BUT NOT
** LIMITED TO, WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE,
** MERCHANTABILITY, INFORMATIONAL CONTENT, NONINFRINGEMENT, OR ERROR-FREE
** OPERATION. CARNEGIE MELLON UNIVERSITY SHALL NOT BE LIABLE FOR INDIRECT,
** SPECIAL OR CONSEQUENTIAL DAMAGES, SUCH AS LOSS OF PROFITS OR INABILITY
** TO USE SAID INTELLECTUAL PROPERTY, UNDER THIS LICENSE, REGARDLESS OF
** WHETHER SUCH PARTY WAS AWARE OF THE POSSIBILITY OF SUCH DAMAGES.
** LICENSEE AGREES THAT IT WILL NOT MAKE ANY WARRANTY ON BEHALF OF
** CARNEGIE MELLON UNIVERSITY, EXPRESS OR IMPLIED, TO ANY PERSON
** CONCERNING THE APPLICATION OF OR THE RESULTS TO BE OBTAINED WITH THE
** DELIVERABLES UNDER THIS LICENSE.
**
** Licensee hereby agrees to defend, indemnify, and hold harmless Carnegie
** Mellon University, its trustees, officers, employees, and agents from
** all claims or demands made against them (and any related losses,
** expenses, or attorney's fees) arising out of, or relating to Licensee's
** and/or its sub licensees' negligent use or willful misuse of or
** negligent conduct or willful misconduct regarding the Software,
** facilities, or other rights or assistance granted by Carnegie Mellon
** University under this License, including, but not limited to, any
** claims of product liability, personal injury, death, damage to
** property, or violation of any laws or regulations.
**
** Carnegie Mellon University Software Engineering Institute authored
** documents are sponsored by the U.S. Department of Defense under
** Contract F19628-00-C-0003. Carnegie Mellon University retains
** copyrights in all material produced under this contract. The U.S.
** Government retains a non-exclusive, royalty-free license to publish or
** reproduce these documents, or allow others to do so, for U.S.
** Government purposes only pursuant to the copyright license under the
** contract clause at 252.227.7013.
**
** @OPENSOURCE_HEADER_END@
*/
#ifndef _PRINT_NETWORK_STRUCTURE_H
#define _PRINT_NETWORK_STRUCTURE_H

#include <silk/silk.h>

RCSIDENTVAR(rcsID_PRINT_NETWORK_STRUCTURE_H, "$SiLK: skprintnets.h 15604 2010-04-08 19:01:04Z mthomas $");

#include <silk/skstream.h>
#include <silk/utils.h>


typedef struct netStruct_st netStruct_t;


int netStructureCreate(
    netStruct_t   **ns,
    int             has_count);

void netStructureSetOutputStream(
    netStruct_t     *ns,
    skstream_t      *stream);

void netStructureDestroy(netStruct_t **ns);

void netStructureSetCountWidth(
    netStruct_t            *ns,
    int                     width);

void netStructureSetNoColumns(netStruct_t *ns);

void netStructureSetNoFinalDelimiter(netStruct_t *ns);

void netStructureSetIpFormat(
    netStruct_t            *ns,
    skipaddr_flags_t        format);

void netStructureSetDelimiter(
    netStruct_t     *ns,
    char             delimiter);

int netStructureParse(
    netStruct_t    *ns,
    const char     *input);


void netStructurePrintIP(
    uint32_t        ip,
    uint64_t       *count,
    netStruct_t    *ns);

void netStructurePrintFinalize(netStruct_t *ns);

void netStructurePrintStatistics(netStruct_t *ns);

#endif /* _PRINT_NETWORK_STRUCTURE_H */

/*
** Local Variables:
** mode:c
** indent-tabs-mode:nil
** c-basic-offset:4
** End:
*/
